@@ -166,7 +166,8 @@ void ExpSep::Init(double *dexpsep)
  */
 
 bool ExpSep::DrawNug(unsigned int n, double **X,  double **F, double *Z, double *lambda, 
-		   double **bmu, double **Vb, double tau2, double itemp, void *state)
+		     double **bmu, double **Vb, double tau2, double itemp, bool cart, 
+		     void *state)
 {
   bool success = false;
   Gp_Prior *gp_prior = (Gp_Prior*) base_prior;
@@ -184,7 +185,7 @@ bool ExpSep::DrawNug(unsigned int n, double **X,  double **F, double *Z, double
 		    Kchol_new, &log_det_K_new, &lambda_new, Vb_new, bmu_new, 
 		    gp_prior->get_b0(), gp_prior->get_Ti(), gp_prior->get_T(), 
 		    tau2, prior->NugAlpha(), prior->NugBeta(), gp_prior->s2Alpha(), 
-		    gp_prior->s2Beta(), (int) linear, itemp, state);
+		    gp_prior->s2Beta(), (int) linear, itemp, (int) cart, state);
   
   /* did we accept the draw? */
   if(nug_new != nug) { nug = nug_new; success = true; swap_new(Vb, bmu, lambda); }
@@ -349,7 +350,7 @@ bool ExpSep::propose_new_d(double* d_new, int * b_new, double *pb_new,
 
 int ExpSep::Draw(unsigned int n, double **F, double **X, double *Z, 
 		 double *lambda, double **bmu, double **Vb, double tau2, 
-		 double itemp, void *state)
+		 double itemp, bool cart, void *state)
 {
   int success = 0;
   bool lin_new;
@@ -368,7 +369,7 @@ int ExpSep::Draw(unsigned int n, double **F, double **X, double *Z,
      and only draw the nugget;  this is done for speed,
      and to improve mixing in the rest of the model */
   if(linear && runi(state) > 0.5)
-    return DrawNug(n, X, F, Z, lambda, bmu, Vb, tau2, itemp, state);
+    return DrawNug(n, X, F, Z, lambda, bmu, Vb, tau2, itemp, cart, state);
 
   /* proposals happen when we're not forcing the LLM */
   if(prior->Linear()) lin_new = true;
@@ -423,7 +424,7 @@ int ExpSep::Draw(unsigned int n, double **F, double **X, double *Z,
 				Vb_new, bmu_new, gp_prior->get_b0(), gp_prior->get_Ti(), 
 				gp_prior->get_T(), tau2, nug, qRatio, 
 				pRatio_log, gp_prior->s2Alpha(), gp_prior->s2Beta(), 
-				(int) lin_new, itemp, state);
+				(int) lin_new, itemp, (int) cart, state);
     
     /* see if the draw was accepted; if so, we need to copy (or swap)
        the contents of the new into the old */
@@ -461,7 +462,7 @@ int ExpSep::Draw(unsigned int n, double **F, double **X, double *Z,
   if(dreject >= REJECTMAX) return -2;
   
   /* draw nugget */
-  bool changed = DrawNug(n, X, F, Z, lambda, bmu, Vb, tau2, itemp, state);
+  bool changed = DrawNug(n, X, F, Z, lambda, bmu, Vb, tau2, itemp, cart, state);
   success = success || changed;
   
   return success;
